#!/usr/bin/env python
# -*- coding: utf_8 -*-

from flask import current_app, jsonify, request
from flask_restful import Resource
from flask_restful.reqparse import RequestParser
from flask_jwt_extended import ( jwt_required, get_jwt_identity )
from application.signal_manager import signalManager
from webcreator.log import logger
from webcreator.response import ResponseCode, response_result


class Treelist(Resource):
    def __init__(self):
        self.parser = RequestParser()
        
    def post(self):
        self.parser.add_argument("page", type=int, location="args", default=1, required=False)
        self.parser.add_argument("pageSize", type=int, location="args", default=10, required=False)
        args = self.parser.parse_args()

        try:
            print("========>", args)
            result, message = signalManager.actionTreelist.emit(args)
            return response_result(message, data=result)
        except Exception as e:
            current_app.logger.error(e)
            return response_result(ResponseCode.HTTP_SERVER_ERROR)

class Treenodes(Resource):
    def __init__(self):
        self.parser = RequestParser()
        
    def get(self):
        self.parser.add_argument("page", type=int, location="args", default=1, required=False)
        self.parser.add_argument("pageSize", type=int, location="args", default=10, required=False)
        args = self.parser.parse_args()

        try:
            print("========>", args)
            result, message = signalManager.actionTreenodes.emit(args)
            return response_result(message, data=result)
        except Exception as e:
            current_app.logger.error(e)
            return response_result(ResponseCode.HTTP_SERVER_ERROR)

class Updatebyid(Resource):
    def __init__(self):
        self.parser = RequestParser()
        
    def post(self):
        self.parser.add_argument("icon", type=str, location="json", default=None, required=False)
        self.parser.add_argument("name", type=str, location="json", default=None, required=False)
        self.parser.add_argument("parentId", type=int, location="json", default=None, required=False)
        self.parser.add_argument("path", type=str, location="json", default=None, required=False)
        self.parser.add_argument("remark", type=str, location="json", default=None, required=False)
        args = self.parser.parse_args()

        try:
            print("========>", args)
            result, message = signalManager.actionUpdatebyid.emit(args)
            return response_result(message, data=result)
        except Exception as e:
            current_app.logger.error(e)
            return response_result(ResponseCode.HTTP_SERVER_ERROR)

